package commands

import (
	"regexp"

	"github.com/rs/zerolog/log"
	"github.com/spf13/cobra"
	"github.com/vleeuwenmenno/kcm/src/models"
	"golang.design/x/clipboard"
)

// NewSearchCmd creates a new search command for history entries using regex
func NewSearchCmd(history *models.History) *cobra.Command {
	return &cobra.Command{
		Use:   "search [regex]",
		Short: "Search clipboard history entries using a regex pattern",
		Args:  cobra.ExactArgs(1),
		Run: func(cmd *cobra.Command, args []string) {
			pattern := args[0]
			re, err := regexp.Compile(pattern)
			if err != nil {
				log.Fatal().Err(err).Str("pattern", pattern).Msg("Invalid regex")
			}

			found := false
			for i, item := range history.Items {
				// Only search text entries
				if item.DataType == clipboard.FmtText {
					if re.Match(item.Data) {
						log.Info().Int("index", i).Str("match", string(item.Data)).Msg("Regex match found")
						found = true
					}
				}
			}
			if !found {
				log.Info().Str("pattern", pattern).Msg("No matches found")
			}
		},
	}
}
